@@ -4,7 +4,8 @@
 CREATE TABLE OPLIST_STAT
 (
   OPSID    NUMBER(12)                           NOT NULL,
-  OPSTEXT  VARCHAR2(201 BYTE)                   NOT NULL
+  OPSTEXT  VARCHAR2(201 BYTE)                   NOT NULL,
+  ACTIVE   NUMBER(1)           DEFAULT 1        NOT NULL,
 )
 TABLESPACE USER_DATA
 /
@@ -12,6 +13,7 @@ COMMENT ON TABLE OPLIST_STAT IS 'Tabelle zur Speicherung der Stati';
 /
 COMMENT ON COLUMN OPLIST_STAT.OPSID IS 'PK';
 COMMENT ON COLUMN OPLIST_STAT.OPSTEXT IS 'Statusbezeichnung';
+COMMENT ON COLUMN OPLIST_STAT.ACTIVE IS 'Status ist in Verwendung (1) oder nicht (0)';
 /
 CREATE UNIQUE INDEX PKOPLISTSTAT ON OPLIST_STAT
 (OPSID)
@@ -29,7 +31,8 @@ ALTER TABLE OPLIST_STAT ADD (
 ----------------------------------------------------------------------
 CREATE TABLE OPLIST_AREA (
     OPAID           NUMBER(12)                              NOT NULL,
-    OPATEXT         VARCHAR2(255)                           NOT NULL
+    OPATEXT         VARCHAR2(255)                           NOT NULL,
+    ACTIVE          NUMBER(1)          DEFAULT 1            NOT NULL
 )
 TABLESPACE USER_DATA;
 /
@@ -37,6 +40,7 @@ COMMENT ON TABLE OPLIST_AREA IS 'Tabelle zur Speicherung der Bereiche';
 /
 COMMENT ON COLUMN OPLIST_AREA.OPAID IS 'PK';
 COMMENT ON COLUMN OPLIST_AREA.OPATEXT IS 'Bereich';
+COMMENT ON COLUMN OPLIST_AREA.ACTIVE IS 'Soll angezeigt werden (1) oder nicht (0)';
 /
 ALTER TABLE OPLIST_AREA ADD (
   CONSTRAINT PKOPLISTAREA
@@ -51,7 +55,8 @@ TABLESPACE USER_INDEX;
 ----------------------------------------------------------------------
 CREATE TABLE OPLIST_PRODUCT (
     OPPID           NUMBER(12)                              NOT NULL,
-    OPPTEXT         VARCHAR2(255)                           NOT NULL
+    OPPTEXT         VARCHAR2(255)                           NOT NULL,
+    ACTIVE          NUMBER(1)         DEFAULT 1             NOT NULL
 )
 TABLESPACE USER_DATA;
 /
@@ -59,6 +64,7 @@ COMMENT ON TABLE OPLIST_PRODUCT IS 'Tabelle zur Speicherung der Produkte';
 /
 COMMENT ON COLUMN OPLIST_PRODUCT.OPPID IS 'PK';
 COMMENT ON COLUMN OPLIST_PRODUCT.OPPTEXT IS 'Produkt';
+COMMENT ON COLUMN OPLIST_PRODUCT.ACTIVE IS 'Produkt wird angezeigt (1) oder nicht (0)';
 /
 ALTER TABLE OPLIST_PRODUCT ADD (
   CONSTRAINT PKOPLISTPRODUCT
@@ -73,7 +79,8 @@ TABLESPACE USER_INDEX;
 ----------------------------------------------------------------------
 CREATE TABLE OPLIST_GROUP (
     OPGID            NUMBER(12)                             NOT NULL,
-    OPGTEXT          VARCHAR2(20)                           NOT NULL
+    OPGTEXT          VARCHAR2(20)                           NOT NULL,
+    ACTIVE           NUMBER(1)        DEFAULT 1             NOT NULL
 )
 TABLESPACE USER_DATA;
 /
@@ -81,6 +88,7 @@ COMMENT ON TABLE OPLIST_GROUP IS 'Tabelle zur Speicherung der Benutzergruppen';
 /
 COMMENT ON COLUMN OPLIST_GROUP.OPGID IS 'PK';
 COMMENT ON COLUMN OPLIST_GROUP.OPGTEXT IS 'Benutzergruppe';
+COMMENT ON COLUMN OPLIST_GROUP.ACTIVE IS 'Gruppe wird angezeigt (1) oder nicht (0)';
 /
 ALTER TABLE OPLIST_GROUP ADD (
   CONSTRAINT PKOPLISTGROUP
