@@ -31,6 +31,9 @@
 #                 aktualisiert
 # 2015-01-16 Paco Installationspaket schreibt nun automatisch die
 #                 zu verwendende Datenbank in die Konfigurationsdatei
+# 2015-02-01 Paco oplist.js, oplist.css und sort.js werden aus dem
+#                 root-Verzeichnis von OPList geloescht
+# 2015-08-09 Paco Installation beruecksichtigt indiv-php-Seiten
 ######################################################################
 TARGETDIR=/srv/www/htdocs
 APPDIR=/u01/app
@@ -262,8 +265,7 @@ main() {
 
     if [ ${UPDATEYES} -eq 0 ]; then
         askUserIfInstallationShouldStart
-    fi 
-    
+    fi
 
     if [ $? -eq 0 ]; then
         echo "Installation wird durchgeführt"
@@ -293,17 +295,54 @@ main() {
 
     # falls index.php bereits existiert (update) --> Sicherung
     if [ -f  ${TARGETDIR}/oplist/index.php ]; then
-        echo "Sichere <${TARGETDIR}/oplist/index.php> um nach <${TARGETDIR}/oplist/index.php_`date +%Y_%m_%d-%H_%M_%S`>"
+        GLATEMPTIMESTAMP=`date +%Y_%m_%d-%H_%M_%S`
+        echo "Sichere <${TARGETDIR}/oplist/index.php> um nach <${TARGETDIR}/oplist/index.php_${GLATEMPTIMESTAMP}>"
         if [ ${DEBUG} -eq 0 ]; then
-            cp ${TARGETDIR}/oplist/index.php ${TARGETDIR}/oplist/index.php_`date +%Y_%m_%d-%H_%M_%S`
+            cp ${TARGETDIR}/oplist/index.php ${TARGETDIR}/oplist/index.php_${GLATEMPTIMESTAMP}
         fi
     fi
+    
+    # falls include/update.php bereits existiert --> Sicherung
+    if [ -f  ${TARGETDIR}/oplist/include/update.php ]; then
+        GLATEMPTIMESTAMP=`date +%Y_%m_%d-%H_%M_%S`
+        echo "Sichere <${TARGETDIR}/oplist/include/update.php> um nach <${TARGETDIR}/oplist/include/update.php_${GLATEMPTIMESTAMP}>"
+        if [ ${DEBUG} -eq 0 ]; then
+            cp ${TARGETDIR}/oplist/include/update.php ${TARGETDIR}/oplist/include/update.php_${GLATEMPTIMESTAMP}
+        fi
+    fi
+
+    # falls oplist.js im root-Verzeichnis existiert (alte Version)
+    # wird diese geloescht
+    if [ -f  ${TARGETDIR}/oplist/oplist.js ]; then
+        rm ${TARGETDIR}/oplist/oplist.js
+    fi
+
+    # falls sort.js im root-Verzeichnis existiert (alte Version)
+    # wird diese geloescht
+    if [ -f  ${TARGETDIR}/oplist/sort.js ]; then
+        rm ${TARGETDIR}/oplist/sort.js
+    fi
+
+    # falls oplist.css im root-Verzeichnis existiert (alte Version)
+    # wird diese geloescht
+    if [ -f  ${TARGETDIR}/oplist/oplist.css ]; then
+        rm ${TARGETDIR}/oplist/oplist.css
+    fi
 
     # extrahieren der Dateien
     echo "Extrahiere <${ZIPFILE}>"
     if [ ${DEBUG} -eq 0 ]; then
         tar xfvz ${ZIPFILE}
     fi
+    
+    # falls include/index_indiv.php nicht existiert --> Template umbenennen
+    if [ ! -f  ${TARGETDIR}/oplist/include/index_indiv.php ]; then
+        # wir benennen das Template um
+        echo "Benenne Vorlage <${TARGETDIR}/oplist/include/index_indiv.php.template> um nach <${TARGETDIR}/oplist/include/index_indiv.php>"
+        if [ ${DEBUG} -eq 0 ]; then
+            cp ${TARGETDIR}/oplist/include/index_indiv.php.template ${TARGETDIR}/oplist/include/index_indiv.php
+        fi
+    fi
 
     # Rechte setzen
     echo "Recht <root:${GROUP}> für <oplist>"
@@ -369,9 +408,9 @@ main() {
                 # Datenmodell ausfuehren
                 if [ ${DBTYPE} = "oracle" ]; then
                     sqlplus ${SCHEMA}/${SCHEMA}@${SID} @create-oracle-db-model-oplist.sql
-                    sqlplus ${SCHEMA}/${SCHEMA}@${SID} @update-oracle-db-model-oplist.sql
+                    #sqlplus ${SCHEMA}/${SCHEMA}@${SID} @update-oracle-db-model-oplist.sql
                     sqlplus ${SCHEMA}/${SCHEMA}@${SID} @merge-oracle-base-entries-oplist.sql
-                    
+
                     # setze die installierten Parameter direkt in die Konfigurationsdatei
                     echo " " >> ${TARGETDIR}/oplist/conf/oplist.ini
                     echo "; ####------------------------------------------------------------------" >> ${TARGETDIR}/oplist/conf/oplist.ini
@@ -385,7 +424,7 @@ main() {
                     echo "oraclePassword = \"${SCHEMA}\";" >> ${TARGETDIR}/oplist/conf/oplist.ini
                 else
                     mysql -h ${DBHOST} -u ${SCHEMA} -p ${PASSWD} ${SID} < create-mysql-db-model-oplist.sql
-                    mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < update-mysql-db-model-oplist.sql
+                    #mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < update-mysql-db-model-oplist.sql
                     mysql -f -h ${DBHOST} -u${SCHEMA} -p${PASSWD} ${SID} < merge-mysql-base-entries-oplist.sql
 
                     # setze die installierten Parameter direkt in die Konfigurationsdatei
